==> hdrhistogram-7.3.0.crate: hdrhistogram-7.3.0/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)

## [Unreleased]
### Added

### Changed

### Removed

## [7.3.0] - 2021-05-04
### Added
 - Implementations of `Add` and `Sub` for `Histogram<T>`.

### Changed
 - Fixed benchmarks, which didn't compile.

## [7.2.0] - 2020-11-29
### Changed
- Minimum supported Rust version bumped to 1.44 (due to `nom 6`)
- `crossbeam-channel` dependency was bumped to 0.5
- `nom` dependency was bumped to 6.0.1
- `base64` dependency was bumped to 0.13

## [7.1.0] - 2020-05-21
### Changed
- Minimal rust version was increased to 1.37.0
- `base64` dependency was bumped to 0.12

## [7.0.0] - 2019-12-20
### Added
- `std::error:Error` implementation for internal Error types: `CreationError`, `AdditionError`, `SubtractionError`, `RecordError`, `UsizeTypeTooSmall`, `DeserializeError`, `IntervalLogWriterError`, `V2DeflateSerializeError`, `V2SerializeError`
- Changelog

### Changed
- `DeserializeError` and `V2DeflateSerializeError` lost derived traits: `PartialEq`, `Eq`, `Clone`, `Copy`
- Inner error type from `std::io::ErrorKind` to `std::io::Error` in types: `DeserializeError`, `V2DeflateSerializeError`, `V2SerializeError`, `IntervalLogWriterError` to support `Display`.

[Unreleased]: https://github.com/HdrHistogram/HdrHistogram_rust/compare/v7.3.0...HEAD
[7.3.0]: https://github.com/HdrHistogram/HdrHistogram_rust/compare/v7.2.0...v7.3.0
[7.2.0]: https://github.com/HdrHistogram/HdrHistogram_rust/compare/v7.1.0...v7.2.0
[7.1.0]: https://github.com/HdrHistogram/HdrHistogram_rust/compare/v7.0.0...v7.1.0
[7.0.0]: https://github.com/HdrHistogram/HdrHistogram_rust/compare/v6.3.4...v7.0.0

==> hdrhistogram-7.4.0.crate: hdrhistogram-7.4.0/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)

## [Unreleased]
### Added

### Changed

### Removed

## [7.4.0] - 2021-10-24

### Changed
- Minimum supported Rust version bumped to 1.48 (due to `nom 7`)
- `nom` dependency was bumped to 7.0.0 ([#102])

[#102]: https://github.com/HdrHistogram/HdrHistogram_rust/pull/102

## [7.3.0] - 2021-05-04
### Added
 - Implementations of `Add` and `Sub` for `Histogram<T>`.

### Changed
 - Fixed benchmarks, which didn't compile.

## [7.2.0] - 2020-11-29
### Changed
- Minimum supported Rust version bumped to 1.44 (due to `nom 6`)
- `crossbeam-channel` dependency was bumped to 0.5
- `nom` dependency was bumped to 6.0.1
- `base64` dependency was bumped to 0.13

## [7.1.0] - 2020-05-21
### Changed
- Minimal rust version was increased to 1.37.0
- `base64` dependency was bumped to 0.12

## [7.0.0] - 2019-12-20
### Added
- `std::error:Error` implementation for internal Error types: `CreationError`, `AdditionError`, `SubtractionError`, `RecordError`, `UsizeTypeTooSmall`, `DeserializeError`, `IntervalLogWriterError`, `V2DeflateSerializeError`, `V2SerializeError`
- Changelog

### Changed
- `DeserializeError` and `V2DeflateSerializeError` lost derived traits: `PartialEq`, `Eq`, `Clone`, `Copy`
- Inner error type from `std::io::ErrorKind` to `std::io::Error` in types: `DeserializeError`, `V2DeflateSerializeError`, `V2SerializeError`, `IntervalLogWriterError` to support `Display`.

[Unreleased]: https://github.com/HdrHistogram/HdrHistogram_rust/compare/v7.4.0...HEAD
[7.4.0]: https://github.com/HdrHistogram/HdrHistogram_rust/compare/v7.3.0...v7.4.0
[7.3.0]: https://github.com/HdrHistogram/HdrHistogram_rust/compare/v7.2.0...v7.3.0
[7.2.0]: https://github.com/HdrHistogram/HdrHistogram_rust/compare/v7.1.0...v7.2.0
[7.1.0]: https://github.com/HdrHistogram/HdrHistogram_rust/compare/v7.0.0...v7.1.0
[7.0.0]: https://github.com/HdrHistogram/HdrHistogram_rust/compare/v6.3.4...v7.0.0
